// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 51 Franklin Street, Fifth
// Floor, Boston, MA 02110-1301, USA.
//
//

// Code:
#include <QApplication>
#include <QtCore>
#include "tup.h"

/**
 * Main function:
 * Setting up the GUI
 * Fetching the user locale
 * Translating the application to the user locale
 * Add the application icon
 * Show the window and launch the main loop
 *
 *
 * @param argc number of arguments
 * @param argv arguments
 *
 * @return error code
 */
int main(int argc, char *argv[])
{
  QApplication app(argc, argv);
  Tup *tupWindow;		/**< the main window */
  QTranslator appTranslator;	/**< application translator */
  QTranslator qtTranslator;	/**< qt translator */
  QString locale = QLocale::system().name(); /**< fetching user locale */
  QIcon icon;

  /// translation
  qtTranslator.load("qt_" + locale,
		    QLibraryInfo::location(QLibraryInfo::TranslationsPath));
  app.installTranslator(&qtTranslator);
  appTranslator.load(QApplication::applicationDirPath() +
		     QString("/tup_") + locale);
  app.installTranslator(&appTranslator);
  /// setting up the gui
  tupWindow = new Tup(&appTranslator);
  tupWindow->setWindowTitle("Tugs' Uptime Project - " \
			    "By ThArGos " + tupWindow->getVersion());
  /// application icon
  icon.addFile(QString::fromUtf8(":/tup/resources/tup.ico"), QSize(), \
	       QIcon::Normal, QIcon::Off);
  tupWindow->setWindowIcon(icon);
  /// show the window
  tupWindow->show();

  return app.exec();
}



//
// main.cpp ends here
